SystemOrganization addCategory: #ConfigurationOfPinocchio!

Object subclass: #ConfigurationOfPinocchio
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfPinocchio'!

!ConfigurationOfPinocchio class methodsFor: 'development support' stamp: 'CamilloBruni 1/27/2012 18:02'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfPinocchio class methodsFor: 'private' stamp: 'CamilloBruni 1/27/2012 18:02'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfPinocchio class methodsFor: 'development support' stamp: 'CamilloBruni 3/28/2012 11:35'!
commit: commitMessage
	"Release #development version: set version blessing to #release, update the #development and #stable symbolic version methods and save the configuration."

	"self releaseDevelopmentVersion: '- release version 1.0.2'"

	<apiDocumentation>
	self ensureMetacello.
	self updateConfiguration.
	self createNewDevelopmentVersion.
	(Smalltalk at: #MetacelloToolBox) updateToLatestPackageVersionsIn: self description: commitMessage.
	[ self saveModifiedPackagesAndConfiguration: commitMessage ] on: Warning do: [ :w| w resume ].
	self loadDevelopment.
	self saveConfiguration: commitMessage.! !

!ConfigurationOfPinocchio class methodsFor: 'development support' stamp: 'abc 2/6/2012 16:20'!
compareVersions
	"Compare the #stable version to #development version"

	"self compareVersions"

	<apiDocumentation>
	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) compareVersionsIn: self) inspect
! !

!ConfigurationOfPinocchio class methodsFor: 'development support' stamp: 'abc 2/6/2012 16:20'!
createNewBaselineVersion
	"Create a new baseline version based upon the #stable version's baseline.
	 A new baseline should be created if new packages have been added or package dependencies have changed."

	"self createNewDevelopmentVersion"

	<apiDocumentation>
	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) createNewBaselineVersionIn: self description: ''
! !

!ConfigurationOfPinocchio class methodsFor: 'development support' stamp: 'abc 2/6/2012 16:20'!
createNewDevelopmentVersion
	"Create a new development version using the #stable version as model."

	"self createNewDevelopmentVersion"

	<apiDocumentation>
	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) createNewDevelopmentVersionIn: self description: ''! !

!ConfigurationOfPinocchio class methodsFor: 'private' stamp: 'CamilloBruni 1/27/2012 18:02'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfPinocchio class methodsFor: 'private' stamp: 'CamilloBruni 1/27/2012 18:02'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfPinocchio class methodsFor: 'metacello tool support' stamp: 'CamilloBruni 1/27/2012 18:02'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfPinocchio class methodsFor: 'loading' stamp: 'CamilloBruni 1/27/2012 18:02'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfPinocchio class methodsFor: 'loading' stamp: 'CamilloBruni 1/27/2012 18:02'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfPinocchio class methodsFor: 'loading' stamp: 'CamilloBruni 1/27/2012 18:02'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfPinocchio class methodsFor: 'accessing' stamp: 'CamilloBruni 1/27/2012 18:02'!
project

	^self new project! !

!ConfigurationOfPinocchio class methodsFor: 'development support' stamp: 'CamilloBruni 2/6/2012 18:19'!
releaseDevelopmentVersion: commitMessage
	"Release #development version: set version blessing to #release, update the #development and #stable symbolic version methods and save the configuration."

	"self releaseDevelopmentVersion: '- release version 1.0.2'"

	<apiDocumentation>
	self ensureMetacello.
	self updateConfiguration.
	self loadDevelopment.
	self createNewDevelopmentVersion.
	(Smalltalk at: #MetacelloToolBox) releaseDevelopmentVersionIn: self description: commitMessage! !

!ConfigurationOfPinocchio class methodsFor: 'development support' stamp: 'abc 2/6/2012 16:20'!
saveConfiguration: commitMessage
	"Save mcz file that contains the configuration to it's repository."

	"self saveConfiguration: '- fixed bug'"

	<apiDocumentation>
	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveConfigurationPackageFor: self name asString description: commitMessage! !

!ConfigurationOfPinocchio class methodsFor: 'development support' stamp: 'CamilloBruni 2/6/2012 18:03'!
saveModifiedPackagesAndConfiguration: commitMessage
	"Save modified mcz files, update the #development version and then save the configuration."

	"self saveModifiedPackagesAndConfiguration: '- fixed bug'"

	<apiDocumentation>
	self ensureMetacello.
	self updateConfiguration.
	(Smalltalk at: #MetacelloToolBox) saveModifiedPackagesAndConfigurationIn: self description: commitMessage! !

!ConfigurationOfPinocchio class methodsFor: 'development support' stamp: 'CamilloBruni 2/6/2012 18:09'!
updateConfiguration
	[[ 
		(Smalltalk at: #Gofer) new
			package: self name;
			merge 
		] on: (Smalltalk at: #MCMergeOrLoadWarning ifAbsent: [ nil ]) do: [ :e| e resume: false ]
	] on: (Smalltalk at: #MCNoChangesException ifAbsent: [ nil ]) do: [ :e| e resume].! !

!ConfigurationOfPinocchio class methodsFor: 'development support' stamp: 'abc 2/6/2012 16:21'!
updateToLatestPackageVersions: descriptionString
	"Update the #development version to match currently loaded mcz files."

	"self updateToLatestPackageVersions: '- fixed a bug'"

	<apiDocumentation>
	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) updateToLatestPackageVersionsIn: self description: descriptionString) isEmpty
		ifTrue: [ self inform: 'All specs up to date' ]! !

!ConfigurationOfPinocchio class methodsFor: 'development support' stamp: 'CamilloBruni 1/27/2012 18:02'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfPinocchio methodsFor: 'baselines' stamp: 'CamilloBruni 2/16/2012 16:01'!
baseline01: spec 
	<version: '0.1-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://ss3.gemstone.com/ss/p'.
			
		spec 
			project: 'AST-Interpreter' with: [
				spec
					className: 'ConfigurationOfASTInterpreter';
					versionString: #'development';
					loads: #( 'test' );
					repository: 'http://ss3.gemstone.com/ss/ASTDebugger' ].
				
		spec 
			package: 'P4-Extension';
			package: 'P4-Kernel' with: [
				spec requires: #('P4-Extension')];
			package: 'P4-SystemSpec' with: [
				spec requires: #('P4-Kernel')];
			package: 'P4-SystemInstaller' with: [
				spec requires: #('P4-Kernel' 'P4-SystemSpec' 'P4-PharoBridge' 'P4-Stream' 'P4-ASM' 'P4-TAC' 'P4-Compiler' 'P4-Exec' 'P4-Extension' 'P4-Examples' 'P4-Test' 'AST-Interpreter')];
			package: 'P4-ASM' with: [
				spec requires: #('P4-Kernel')];
			package: 'P4-Compiler' with: [
				spec requires: #('P4-Kernel')];
			package: 'P4-Examples' with: [
				spec requires: #('P4-Kernel')];
			package: 'P4-Exec' with: [
				spec requires: #('P4-Kernel')];
			package: 'P4-PharoBridge'with: [
				spec requires: #('P4-Kernel')];
			package: 'P4-Stream' with: [
				spec requires: #('P4-Kernel')];
			package: 'P4-TAC'with: [
				spec requires: #('P4-Stream')];
			package: 'P4-SSA';
			package: 'P4-Test' with: [
				spec requires: #('P4-Kernel')].
			
		spec 
			group: 'default' with: #('P4-SystemInstaller')]
! !

!ConfigurationOfPinocchio methodsFor: 'baselines' stamp: 'CamilloBruni 3/28/2012 13:08'!
baseline02: spec 
	<version: '0.2-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://ss3.gemstone.com/ss/p'.
			
		spec 
			project: 'AST-Interpreter' with: [
				spec
					className: 'ConfigurationOfASTInterpreter';
					versionString: #'development';
					loads: #( 'test' );
					repository: 'http://ss3.gemstone.com/ss/ASTDebugger' ].
				
		spec 
			package: 'P4-Extension';
			package: 'P4-Kernel' with: [
				spec requires: #('P4-Extension')];
			package: 'P4-SystemSpec' with: [
				spec requires: #('P4-Kernel')];
			package: 'P4-SystemInstaller' with: [
				spec requires: #('P4-Kernel' 'P4-SystemSpec' 'P4-PharoBridge' 'P4-Stream' 'P4-ASM' 'P4-TAC' 'P4-Compiler' 'P4-Exec' 'P4-Extension' 'P4-Examples' 'P4-Test' 'AST-Interpreter')];
			package: 'P4-ASM' with: [
				spec requires: #('P4-Kernel')];
			package: 'P4-Compiler' with: [
				spec requires: #('P4-Kernel')];
			package: 'P4-Examples' with: [
				spec requires: #('P4-Kernel')];
			package: 'P4-Exec' with: [
				spec requires: #('P4-Kernel')];
			package: 'P4-PharoBridge'with: [
				spec requires: #('P4-Kernel')];
			package: 'P4-Stream' with: [
				spec requires: #('P4-Kernel')];
			package: 'P4-TAC'with: [
				spec requires: #('P4-Stream')];
			package: 'P4-SSA' with: [
				spec requires: #('P4-Kernel')];
			package: 'P4-Test' with: [
				spec requires: #('P4-Kernel')].
			
		spec 
			group: 'default' with: #('P4-SystemInstaller')]
! !

!ConfigurationOfPinocchio methodsFor: 'baselines' stamp: 'CamilloBruni 4/4/2012 17:46'!
baseline03: spec 
	<version: '0.3-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://ss3.gemstone.com/ss/p'.
			
		spec 
			project: 'AST-Interpreter' with: [
				spec
					className: 'ConfigurationOfASTInterpreter';
					versionString: #'development';
					loads: #( 'test' );
					repository: 'http://ss3.gemstone.com/ss/ASTDebugger' ].
		
		spec
			project: 'AsmJit' with: [
				spec
					className: 'ConfigurationOfNativeBoost';
					versionString: #development;
					loads: #( 'AsmJit' );
					repository: 'http://www.squeaksource.com/NativeBoost'
				].
		
		spec 
			package: 'P4-Extension';
			package: 'P4-Kernel' with: [
				spec requires: #('P4-Extension' 'AsmJit')];
			package: 'P4-SystemSpec' with: [
				spec requires: #('P4-Kernel')];
			package: 'P4-SystemInstaller' with: [
				spec requires: #('P4-Kernel' 'P4-SystemSpec' 'P4-PharoBridge' 'P4-Stream' 'P4-ASM' 'P4-TAC' 'P4-Compiler' 'P4-Exec' 'P4-Extension' 'P4-Examples' 'P4-Test' 'AST-Interpreter' 'AsmJit')];
			package: 'P4-ASM' with: [
				spec requires: #('P4-Kernel')];
			package: 'P4-Compiler' with: [
				spec requires: #('P4-Kernel')];
			package: 'P4-Examples' with: [
				spec requires: #('P4-Kernel')];
			package: 'P4-Exec' with: [
				spec requires: #('P4-Kernel')];
			package: 'P4-PharoBridge'with: [
				spec requires: #('P4-Kernel')];
			package: 'P4-Stream' with: [
				spec requires: #('P4-Kernel')];
			package: 'P4-TAC'with: [
				spec requires: #('P4-Stream' 'AsmJit')];
			package: 'P4-SSA' with: [
				spec requires: #('P4-Kernel' 'AsmJit')];
			package: 'P4-Test' with: [
				spec requires: #('P4-Kernel')].
			
		spec 
			group: 'default' with: #('P4-SystemInstaller')]
! !

!ConfigurationOfPinocchio methodsFor: 'baselines' stamp: 'CamilloBruni 5/31/2012 15:18'!
baseline04: spec 
	<version: '0.4-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://smalltalkhub.com/mc/dh83/p/main'.
			
		spec 
			project: 'AST-Interpreter' with: [
				spec
					className: 'ConfigurationOfASTInterpreter';
					versionString: #'development';
					loads: #( 'test' );
					repository: 'http://ss3.gemstone.com/ss/ASTDebugger' ].
		
		spec
			project: 'AsmJit' with: [
				spec
					className: 'ConfigurationOfNativeBoost';
					versionString: #development;
					loads: #( 'AsmJit' );
					repository: 'http://www.squeaksource.com/NativeBoost'
				].
		
		spec 
			package: 'P4-Extension';
			package: 'P4-Kernel' with: [
				spec requires: #('P4-Extension' 'AsmJit')];
			package: 'P4-SystemSpec' with: [
				spec requires: #('P4-Kernel')];
			package: 'P4-SystemInstaller' with: [
				spec requires: #('P4-Kernel' 'P4-SystemSpec' 'P4-PharoBridge' 'P4-Stream' 'P4-ASM' 'P4-TAC' 'P4-Compiler' 'P4-Exec' 'P4-Extension' 'P4-Examples' 'P4-Test' 'AST-Interpreter' 'AsmJit')];
			package: 'P4-ASM' with: [
				spec requires: #('P4-Kernel')];
			package: 'P4-Compiler' with: [
				spec requires: #('P4-Kernel')];
			package: 'P4-Examples' with: [
				spec requires: #('P4-Kernel')];
			package: 'P4-Exec' with: [
				spec requires: #('P4-Kernel')];
			package: 'P4-PharoBridge'with: [
				spec requires: #('P4-Kernel')];
			package: 'P4-Stream' with: [
				spec requires: #('P4-Kernel')];
			package: 'P4-TAC'with: [
				spec requires: #('P4-Stream' 'AsmJit')];
			package: 'P4-SSA' with: [
				spec requires: #('P4-Kernel' 'AsmJit')];
			package: 'P4-Test' with: [
				spec requires: #('P4-Kernel')].
			
		spec 
			group: 'default' with: #('P4-SystemInstaller')]
! !

!ConfigurationOfPinocchio methodsFor: 'symbolic versions' stamp: 'CamilloBruni 6/21/2012 13:36'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '0.4'.
! !

!ConfigurationOfPinocchio methodsFor: 'accessing' stamp: 'CamilloBruni 1/27/2012 18:02'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfPinocchio methodsFor: 'symbolic versions' stamp: 'CamilloBruni 3/28/2012 11:25'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'common' version: '0.3'
! !

!ConfigurationOfPinocchio methodsFor: 'versions' stamp: 'CamilloBruni 2/6/2012 18:13'!
version01: spec
	<version: '0.1' imports: #('0.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: 'First release
fixed exporting
adding SSA
adding SSA
adding SSA
adding SSA
adding SSA
adding SSA2
adding SSA2
adding SSA2
adding guards instead of goto'.
		spec author: 'ToonVerwaest'.
		spec timestamp: '2/6/2012 18:06'.
		spec 
			package: 'P4-ASM' with: 'P4-ASM-CamilloBruni.1';
			package: 'P4-Compiler' with: 'P4-Compiler-abc.2';
			package: 'P4-Examples' with: 'P4-Examples-CamilloBruni.1';
			package: 'P4-Exec' with: 'P4-Exec-CamilloBruni.1';
			package: 'P4-Extension' with: 'P4-Extension-CamilloBruni.2';
			package: 'P4-Kernel' with: 'P4-Kernel-abc.3';
			package: 'P4-PharoBridge' with: 'P4-PharoBridge-CamilloBruni.1';
			package: 'P4-Stream' with: 'P4-Stream-CamilloBruni.2';
			package: 'P4-SystemInstaller' with: 'P4-SystemInstaller-abc.4';
			package: 'P4-SystemSpec' with: 'P4-SystemSpec-abc.2';
			package: 'P4-TAC' with: 'P4-TAC-abc.4';
			package: 'P4-SSA' with: 'P4-SSA-ToonVerwaest.2';
			package: 'P4-Test' with: 'P4-Test-CamilloBruni.1'. ].
! !

!ConfigurationOfPinocchio methodsFor: 'versions' stamp: 'CamilloBruni 2/6/2012 18:19'!
version02: spec
	<version: '0.2' imports: #('0.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: ''.
		spec author: 'CamilloBruni'.
		spec timestamp: '2/6/2012 18:19'.
		spec 
			package: 'P4-ASM' with: 'P4-ASM-CamilloBruni.1';
			package: 'P4-Compiler' with: 'P4-Compiler-abc.2';
			package: 'P4-Examples' with: 'P4-Examples-CamilloBruni.1';
			package: 'P4-Exec' with: 'P4-Exec-CamilloBruni.1';
			package: 'P4-Extension' with: 'P4-Extension-CamilloBruni.2';
			package: 'P4-Kernel' with: 'P4-Kernel-abc.3';
			package: 'P4-PharoBridge' with: 'P4-PharoBridge-CamilloBruni.1';
			package: 'P4-Stream' with: 'P4-Stream-CamilloBruni.2';
			package: 'P4-SystemInstaller' with: 'P4-SystemInstaller-abc.4';
			package: 'P4-SystemSpec' with: 'P4-SystemSpec-abc.2';
			package: 'P4-TAC' with: 'P4-TAC-abc.4';
			package: 'P4-SSA' with: 'P4-SSA-ToonVerwaest.2';
			package: 'P4-Test' with: 'P4-Test-CamilloBruni.1'. ].
! !

!ConfigurationOfPinocchio methodsFor: 'versions' stamp: 'CamilloBruni 5/29/2012 16:44'!
version03: spec
	<version: '0.3' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'more comments'.
		spec author: 'CamilloBruni'.
		spec timestamp: '3/14/2012 15:06'.
		spec 
			package: 'P4-ASM' with: 'P4-ASM-CamilloBruni.1';
			package: 'P4-Compiler' with: 'P4-Compiler-abc.2';
			package: 'P4-Examples' with: 'P4-Examples-CamilloBruni.1';
			package: 'P4-Exec' with: 'P4-Exec-CamilloBruni.4';
			package: 'P4-Extension' with: 'P4-Extension-CamilloBruni.2';
			package: 'P4-Kernel' with: 'P4-Kernel-CamilloBruni.4';
			package: 'P4-PharoBridge' with: 'P4-PharoBridge-CamilloBruni.1';
			package: 'P4-Stream' with: 'P4-Stream-CamilloBruni.2';
			package: 'P4-SystemInstaller' with: 'P4-SystemInstaller-CamilloBruni.5';
			package: 'P4-SystemSpec' with: 'P4-SystemSpec-CamilloBruni.3';
			package: 'P4-TAC' with: 'P4-TAC-abc.4';
			package: 'P4-SSA' with: 'P4-SSA-ToonVerwaest.2';
			package: 'P4-Test' with: 'P4-Test-CamilloBruni.1'. ].
! !

!ConfigurationOfPinocchio methodsFor: 'versions' stamp: 'CamilloBruni 6/21/2012 13:36'!
version04: spec
	<version: '0.4' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '...'.
		spec author: 'CamilloBruni'.
		spec timestamp: '6/21/2012 13:36'.
		spec 
			package: 'P4-ASM' with: 'P4-ASM-CamilloBruni.10';
			package: 'P4-Compiler' with: 'P4-Compiler-CamilloBruni.4';
			package: 'P4-Examples' with: 'P4-Examples-CamilloBruni.1';
			package: 'P4-Exec' with: 'P4-Exec-CamilloBruni.10';
			package: 'P4-Extension' with: 'P4-Extension-CamilloBruni.10';
			package: 'P4-Kernel' with: 'P4-Kernel-CamilloBruni.11';
			package: 'P4-PharoBridge' with: 'P4-PharoBridge-CamilloBruni.1';
			package: 'P4-Stream' with: 'P4-Stream-CamilloBruni.2';
			package: 'P4-SystemInstaller' with: 'P4-SystemInstaller-CamilloBruni.10';
			package: 'P4-SystemSpec' with: 'P4-SystemSpec-CamilloBruni.7';
			package: 'P4-TAC' with: 'P4-TAC-CamilloBruni.11';
			package: 'P4-SSA' with: 'P4-SSA-ToonVerwaest.2';
			package: 'P4-Test' with: 'P4-Test-CamilloBruni.1'. ].
! !

!ConfigurationOfPinocchio methodsFor: 'versions' stamp: 'CamilloBruni 5/31/2012 15:19'!
version05: spec
	<version: '0.5' imports: #('0.4-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: ''.
		spec author: 'CamilloBruni'.
		spec timestamp: '2012-05-31 15:20'.
		spec 
			package: 'P4-ASM' with: 'P4-ASM-CamilloBruni.6';
			package: 'P4-Compiler' with: 'P4-Compiler-CamilloBruni.3';
			package: 'P4-Examples' with: 'P4-Examples-CamilloBruni.1';
			package: 'P4-Exec' with: 'P4-Exec-CamilloBruni.9';
			package: 'P4-Extension' with: 'P4-Extension-CamilloBruni.8';
			package: 'P4-Kernel' with: 'P4-Kernel-CamilloBruni.10';
			package: 'P4-PharoBridge' with: 'P4-PharoBridge-CamilloBruni.1';
			package: 'P4-Stream' with: 'P4-Stream-CamilloBruni.2';
			package: 'P4-SystemInstaller' with: 'P4-SystemInstaller-CamilloBruni.8';
			package: 'P4-SystemSpec' with: 'P4-SystemSpec-CamilloBruni.7';
			package: 'P4-TAC' with: 'P4-TAC-CamilloBruni.8';
			package: 'P4-SSA' with: 'P4-SSA-ToonVerwaest.2';
			package: 'P4-Test' with: 'P4-Test-CamilloBruni.1'. ].
! !
